@@ -24,11 +24,11 @@ Moonshine::Test - Test!
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
@@ -202,6 +202,7 @@ sub moon_test_one {
             catch     => 0,
             key       => 0,
             index     => 0,
+            built     => 0,
         }
     );
 
@@ -370,6 +371,12 @@ sub moon_test_one {
               );
         }
         when ('scalar') {
+            if ($instruction{func} eq 'tag') {
+                use Data::Dumper;
+                warn Dumper $test_name;
+                warn Dumper \@test;
+            }
+            
             return is( $test[0], $expected[0], sprintf "%s is scalar - is - %s",
                 $test_name, $expected[0] );
         }
@@ -382,8 +389,7 @@ sub moon_test_one {
                 "$test_name is array - reference - is_deeply" );
         }
         when ('obj') {
-            return isa_ok( $test[0],
-                $expected[0],
+            return isa_ok( $test[0], $expected[0],
                 "$test_name is Object - blessed - is - $expected[0]" );
         }
         when ('like') {
@@ -418,27 +424,27 @@ sub moon_test_one {
     moon_test(
         name => 'Checking Many Things'
         build => {
-             class => 'Moonshine::Element', 
-             args => {
+            class => 'Moonshine::Element', 
+            args => {
                 tag => 'p',
                 text => 'hello'
-             }
+            }
         },
         instructions => [
             {
                 test => 'scalar',
                 func => 'tag',
-                expected => 'hello',
+                expected => 'p',
             },
-           {
+            {
                 test => 'scalar',
                 action => 'text',
                 expected => 'hello',
-           },
-           { 
+            },
+            { 
                 test => 'render'
                 expected => '<p>hello</p>'
-           },
+            },
         ],
     );
 
@@ -448,7 +454,6 @@ The tests name
 
     name => 'I rule the world',
 
-
 =head3 instance
 
     my $instance = My::Object->new();
@@ -513,6 +518,8 @@ sub moon_test {
         }
     );
 
+    use Data::Dumper;
+
     my $instance =
       $instruction{build}
       ? _build_me( $instruction{build} )
@@ -524,26 +531,30 @@ sub moon_test {
     );
 
     foreach my $test ( @{ $instruction{instructions} } ) {
-        my $subtests = delete $test->{subtest};
         $test_info{tested}++;
+        if ( my $subtests = delete $test->{subtest} ) {
+            my ( $test_name, $new_instance ) = _run_the_code(
+                {
+                    instance => $instance,
+                    %{$test}
+                }
+            );
+
+            my $new_instructions = {
+                instance     => $new_instance,
+                instructions => $subtests,
+                name         => "Subtest -> $instruction{name} -> $test_name",
+            };
+            warn Dumper 'I leave here';
+            moon_test(%{$new_instructions});
+            next;
+        }
+
         $test_info{fail}++
           unless moon_test_one(
             instance => $instance,
             %{$test}
           );
-
-        if ($subtests){
-            my $new_instance = _run_the_code({
-                instance => $instance, 
-                %{$test}
-            });
-            my $new_instructions = {
-                instance => $new_instance,
-                instructions => $subtests,
-                name => "Subtest -> $instruction{name}",
-            };
-            moon_test($new_instructions);
-        }
     }
 
     $test_info{ok} = $test_info{fail} ? 0 : 1;
@@ -617,14 +628,17 @@ sub _run_the_code {
     my $test_name;
     if ( my $func = $instruction->{func} ) {
         $test_name = "function: ${func}";
-        return defined $instruction->{args_list}
-          ? (
-            $test_name,
-            $instruction->{instance}->$func( @{ $instruction->{args} } )
-          )
-          : (
-            $test_name, $instruction->{instance}->$func( $instruction->{args} )
-          );
+        
+        return defined $instruction->{args} 
+            ? defined $instruction->{args_list}
+                ? (
+                    $test_name,
+                    $instruction->{instance}->$func( @{ $instruction->{args} } )
+                  )
+                : (
+                    $test_name, $instruction->{instance}->$func( $instruction->{args} // {})
+                  )
+            : ( $test_name, $instruction->{instance}->$func );
     }
     elsif ( my $meth = $instruction->{meth} ) {
         my $meth_name = svref_2object($meth)->GV->NAME;
